#/bin/bash -e
source config.sh
YahooAnswersCollectionSplitter $@

